#! /usr/bin/env node
/* eslint-disable no-console */

const exploitalert = require('exploitalert');
const meow = require('meow');
const chalk = require('chalk');

const cli = meow(
  `
    Usage
      $ exploitalert <options>

    Options
      -c, --categories            List categories/platforms
      -s, --search <platform>     Search for exploits
      -d, --details <id>          Get exploit details

    Example
      $ exploitalert -c
      $ exploitalert -s wordpress
      $ exploitalert -d 26271
      
`,
  {
    alias: {
      s: 'search',
      d: 'details',
      c: 'categories',
    },
    string: ['s', 'd'],
  },
);

if (Object.keys(cli.flags).length === 0) cli.showHelp();

const { search, details, categories } = cli.flags;

if (search) {
  exploitalert.search(search).then((results) => {
    results.forEach((data) => {
      const output = `${chalk.green(data.id)} - ${data.date} - ${data.name}`;
      console.log(output);
    });
  });
}

if (details) {
  exploitalert.details(details).then((data) => {
    const output = `${chalk.green('Found an exploit:')}
      ${data}`;
    console.log(output);
  });
}

if (categories) {
  exploitalert.categories().then((results) => {
    results.forEach(category => console.log(category));
  });
}
