#! /usr/bin/env node
'use strict';

/* eslint-disable no-console */

var exploitalert = require('exploitalert');
var meow = require('meow');
var chalk = require('chalk');

var cli = meow('\n    Usage\n      $ exploitalert <options>\n\n    Options\n      -c, --categories            List categories/platforms\n      -s, --search <platform>     Search for exploits\n      -d, --details <id>          Get exploit details\n\n    Example\n      $ exploitalert -c\n      $ exploitalert -s wordpress\n      $ exploitalert -d 26271\n      \n', {
  alias: {
    s: 'search',
    d: 'details',
    c: 'categories'
  },
  string: ['s', 'd']
});

if (Object.keys(cli.flags).length === 0) cli.showHelp();

var _cli$flags = cli.flags,
    search = _cli$flags.search,
    details = _cli$flags.details,
    categories = _cli$flags.categories;


if (search) {
  exploitalert.search(search).then(function (results) {
    results.forEach(function (data) {
      var output = chalk.green(data.id) + ' - ' + data.date + ' - ' + data.name;
      console.log(output);
    });
  });
}

if (details) {
  exploitalert.details(details).then(function (data) {
    var output = chalk.green('Found an exploit:') + '\n      ' + data;
    console.log(output);
  });
}

if (categories) {
  exploitalert.categories().then(function (results) {
    results.forEach(function (category) {
      return console.log(category);
    });
  });
}